@@ -241,4 +241,8 @@ class Parametrization(object):
             for j in range(len(self.direction_vectors)):
                 temp += '+ ' + str(self.direction_vectors[j].coordinates[i]) + ' t_{}'.format(j+1)
             ret += '\n' + temp
-        return ret
\ No newline at end of file
+        return ret
+    
+    def __eq__(self, other):
+        return (self.basepoint-other.basepoint).mag() < 0.001\
+            and sum([(x-y).mag() for x, y in zip(self.direction_vectors, other.direction_vectors)]) < 0.001
\ No newline at end of file
